@@ -3,7 +3,7 @@ package Complete::Sah;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2019-12-18'; # DATE
 our $DIST = 'Complete-Sah'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -36,7 +36,12 @@ complete from the `in` clause. Or for something like `[int => between => [1,
 _
     args => {
         schema => {
-            summary => 'Must be normalized',
+            description => <<'_',
+
+Will be normalized, unless when `schema_is_normalized` is set to true, in which
+case schema must already be normalized.
+
+_
             req => 1,
         },
         schema_is_normalized => {
@@ -334,7 +339,7 @@ Complete::Sah - Sah-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.001 of Complete::Sah (from Perl distribution Complete-Sah), released on 2019-12-18.
+This document describes version 0.002 of Complete::Sah (from Perl distribution Complete-Sah), released on 2019-12-18.
 
 =head1 SYNOPSIS
 
@@ -366,7 +371,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
-Must be normalized.
+Will be normalized, unless when C<schema_is_normalized> is set to true, in which
+case schema must already be normalized.
 
 =item * B<schema_is_normalized> => I<bool> (default: 0)
 
